/*
 * Copyright (c) 2010-2011 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.inovat.dua.aggrlzzsdtv.Parameter
 *
 * de.inovat.dua.aggrlzzsdtv.Parameter is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * de.inovat.dua.aggrlzzsdtv.Parameter is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * <p>
 * You should have received a copy of the GNU General Public License
 * along with de.inovat.dua.aggrlzzsdtv.Parameter; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * Koelner Strasse 30
 * D-50859 Koeln
 * +49 (0)2234 4301 800
 * info@invat.de
 * www.inovat.de
 */



package de.inovat.dua.aggrlzzsdtv;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.sys.funclib.debug.Debug;

//~ KLASSEN ===================================================================

/**
 * Singletonklasse zur Verwaltung der Parameter, die für die Aggregation benötigt werden.
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author Dipl.-Ing. Hans Christian Kniß (HCK)
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class Parameter {

    /** DebugLogger für Debug-Ausgaben. */
    private static final Debug debug             = Debug.getLogger();
    private static Parameter   dieEinzigeInstanz = new Parameter();

    //~ FELDER ================================================================

    private long[] _GrenzenBPA = { 40, 50, 60, 70, 80, 90, 100, 110, 120 };
    private long[] _GrenzenLVO = { 40, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140, 150, 160, 170, 180 };
    private long[] _GrenzenSGV = { 40, 50, 60, 70, 80, 90, 100, 110, 120 };

    //~ KONSTRUKTOREN  (und vom Konstruktor verwendete Methoden) ==============

    private Parameter() {

        // Hier die Konstruktion der Instanz durchführen
    }

    //~ GET METHODEN ==========================================================

    public static Parameter getInstanz() {
        return dieEinzigeInstanz;
    }

    //~ METHODEN ==============================================================

    public String ausgabe(long[] parameter) {
        StringBuffer sb = new StringBuffer();

        for (long p : parameter) {
            sb.append(p).append(":");
        }

        // letzten : wieder entfernen
        sb.replace(sb.length() - 1, sb.length(), "");

        return sb.toString();
    }

    //~ GET METHODEN ==========================================================

    public long[] getGrenzenBPA() {
        return _GrenzenBPA;
    }

    public long[] getGrenzenLVO() {
        return _GrenzenLVO;
    }

    public long[] getGrenzenSGV() {
        return _GrenzenSGV;
    }

    //~ METHODEN ==============================================================

    public void initialisiereGrenzenBPA(String grenzenGeschwindigKeitsKlassenBPAAufrufParameter) {
        String[] einzelParam = grenzenGeschwindigKeitsKlassenBPAAufrufParameter.split("(,|;|:)");
        long[]   parameter   = new long[einzelParam.length];

        try {
            for (int i = 0; i < einzelParam.length; i++) {
                parameter[i] = new Long(einzelParam[i]);
            }

            _GrenzenBPA = parameter;
        }
        catch (NumberFormatException e) {
            debug.warning(String.format("Aufrufparameter [-grenzenGeschwindigKeitsKlassenBPA=%s] konnte nicht ausgewertet werden. Vorgaben werden auf BAStStandard gesetzt.", grenzenGeschwindigKeitsKlassenBPAAufrufParameter));
        }
    }

    public void initialisiereGrenzenLVO(String grenzenGeschwindigKeitsKlassenLVOAufrufParameter) {
        String[] einzelParam = grenzenGeschwindigKeitsKlassenLVOAufrufParameter.split("(,|;|:)");
        long[]   parameter   = new long[einzelParam.length];

        try {
            for (int i = 0; i < einzelParam.length; i++) {
                parameter[i] = new Long(einzelParam[i]);
            }

            _GrenzenLVO = parameter;
        }
        catch (NumberFormatException e) {
            debug.warning(String.format("Aufrufparameter [-grenzenGeschwindigKeitsKlassenLVO=%s] konnte nicht ausgewertet werden. Vorgaben werden auf BAStStandard gesetzt.", grenzenGeschwindigKeitsKlassenLVOAufrufParameter));
        }
    }

    public void initialisiereGrenzenSGV(String grenzenGeschwindigKeitsKlassenSGVAufrufParameter) {
        String[] einzelParam = grenzenGeschwindigKeitsKlassenSGVAufrufParameter.split("(,|;|:)");
        long[]   parameter   = new long[einzelParam.length];

        try {
            for (int i = 0; i < einzelParam.length; i++) {
                parameter[i] = new Long(einzelParam[i]);
            }

            _GrenzenSGV = parameter;
        }
        catch (NumberFormatException e) {
            debug.warning(String.format("Aufrufparameter [-grenzenGeschwindigKeitsKlassenSGV=%s] konnte nicht ausgewertet werden. Vorgaben werden auf BAStStandard gesetzt.", grenzenGeschwindigKeitsKlassenSGVAufrufParameter));
        }
    }
}


//~Formatiert mit 'inovat Kodierkonvention' am 08.12.10
